summaryrefslogtreecommitdiff
path: root/python/lowlevelil.py
diff options
context:
space:
mode:
Diffstat (limited to 'python/lowlevelil.py')
-rw-r--r--python/lowlevelil.py12
1 files changed, 8 insertions, 4 deletions
diff --git a/python/lowlevelil.py b/python/lowlevelil.py
index e1128b26..09786cd9 100644
--- a/python/lowlevelil.py
+++ b/python/lowlevelil.py
@@ -4797,15 +4797,17 @@ class LowLevelILFunction:
loc: Optional['ILSourceLocation'] = None
) -> ExpressionIndex:
"""
``mult_double_prec_signed`` multiplies signed with double precision expression ``a`` by expression ``b``,
each ``size`` bytes and potentially setting flags ``flags`` and returning an expression of ``2*size`` bytes.
+ .. note:: The output expression is ``2*size`` bytes in size, but will be rendered as ``muls.dp.<size>``.
+
:param int size: the size of the input operands, in bytes
:param ExpressionIndex a: LHS expression
:param ExpressionIndex b: RHS expression
:param str flags: optional, flags to set
:param ILSourceLocation loc: location of returned expression
- :return: The expression ``muls.dp.<2*size>{<flags>}(a, b)``
+ :return: The expression ``muls.dp.<size>{<flags>}(a, b)``
:rtype: ExpressionIndex
"""
return self.expr(LowLevelILOperation.LLIL_MULS_DP, a, b, size=size, flags=flags, source_location=loc)
@@ -4815,15 +4817,17 @@ class LowLevelILFunction:
loc: Optional['ILSourceLocation'] = None
) -> ExpressionIndex:
"""
``mult_double_prec_unsigned`` multiplies unsigned with double precision expression ``a`` by expression ``b``,
each ``size`` bytes and potentially setting flags ``flags`` and returning an expression of ``2*size`` bytes.
+ .. note:: The output expression is ``2*size`` bytes in size, but will be rendered as ``mulu.dp.<size>``.
+
:param int size: the size of the input operands, in bytes
:param ExpressionIndex a: LHS expression
:param ExpressionIndex b: RHS expression
:param str flags: optional, flags to set
:param ILSourceLocation loc: location of returned expression
- :return: The expression ``mulu.dp.<2*size>{<flags>}(a, b)``
+ :return: The expression ``mulu.dp.<size>{<flags>}(a, b)``
:rtype: ExpressionIndex
"""
return self.expr(LowLevelILOperation.LLIL_MULU_DP, a, b, size=size, flags=flags, source_location=loc)
@@ -4797,15 +4797,17 @@ class LowLevelILFunction:
) -> ExpressionIndex:
"""
- ``mult_double_prec_signed`` multiplies signed with double precision expression ``a`` by expression ``b``,
+ ``mult_double_prec_signed`` multiplies signed with double (2*size bytes) precision expression ``a`` by expression ``b``,
each ``size`` bytes and potentially setting flags ``flags`` and returning an expression of ``2*size`` bytes.
@@ -4815,15 +4817,17 @@ class LowLevelILFunction:
) -> ExpressionIndex:
"""
- ``mult_double_prec_unsigned`` multiplies unsigned with double precision expression ``a`` by expression ``b``,
+ ``mult_double_prec_unsigned`` multiplies unsigned with double (2*size bytes) precision expression ``a`` by expression ``b``,
each ``size`` bytes and potentially setting flags ``flags`` and returning an expression of ``2*size`` bytes.